
/* 	CreateVDWfiles.qs
	Script to create VDW files (normalised diffusion weighted)
*/

/* This information is used in the functions */
	var DTIDataPath 			= "/Users/hester/Data/Human31dir/";
	var today 					= new Date();
	var nameDMR 				= DTIDataPath + "HUMAN31DIR_SCRIPT.dmr";
	var nameVMRinNative 		= DTIDataPath +"human.vmr";
	var nameVMRinAcpc			= DTIDataPath +"human_ACPC.vmr";
	var nameVMRinTal 			= DTIDataPath +"human_TAL.vmr";
	var nameIAfile 				= DTIDataPath + "HUMAN31DIR_SCRIPT-TO-human_IA.trf";
	var nameFAfile 				= DTIDataPath + "HUMAN31DIR_SCRIPT-TO-human_FA.trf";
	var nameACPCfile 			= DTIDataPath + "human_ACPC.trf";
	var nameTALfile 			= DTIDataPath + "human_ACPC.tal";
	var nameVDWinNative			= DTIDataPath + "HUMAN31DIR_SCRIPT_NATIVE.vdw";
	var nameVDWinAcpc			= DTIDataPath + "HUMAN31DIR_SCRIPT_ACPC.vdw";
	var nameVDWinTal			= DTIDataPath + "HUMAN31DIR_SCRIPT_TAL.vdw";
	var dataType                = 2; // integer 2-byte format: 1 or in float format: 2.
	var resolution 				= 3; // one of 1, 2 or 3 mm^2
	var interpolation 			= 1;
	var threshold 				= 100;

/* 	This code is executed when clicking 'Run'
	If an error occurs, it is printed to the BrainVoyager QX Log tab
*/
	BrainVoyagerQX.ShowLogTab();
	BrainVoyagerQX.PrintToLog("Start creating VDWs...");
	try {
		//CreateVDWinNativeSpace();
		//CreateVDWinAcpcSpace();
		CreateVDWinTalSpace();
	} catch (e) {
		BrainVoyagerQX.PrintToLog("Error: " + e);
	}

/* These functions are invoked from the section above */
function CreateVDWinNativeSpace() {

	BrainVoyagerQX.TimeOutMessageBox("This function creates a VDW file in native space...", 5);
	var vmr = BrainVoyagerQX.OpenDocument(nameVMRinNative);
	BrainVoyagerQX.PrintToLog("Start creating VDW in native space...");
	vmr.ExtendedTALSpaceForVTCCreation = false; // this is true or false
	var success = vmr.CreateVDWInVMRSpace(nameDMR, nameIAfile, nameFAfile, nameVDWinNative, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyagerQX.PrintToLog("Created VDW: " + nameVDWinNative);
	} else {
		BrainVoyagerQX.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}

function CreateVDWinAcpcSpace() {

	BrainVoyagerQX.TimeOutMessageBox("This function creates a VDW file in AC-PC space...", 5);
	var vmr = BrainVoyagerQX.OpenDocument(nameVMRinAcpc);
	BrainVoyagerQX.PrintToLog("Start creating VDW in AC-PC space...");
	vmr.ExtendedTALSpaceForVTCCreation = false; // this is true or false
	var success = vmr.CreateVDWInACPCSpace(nameDMR, nameIAfile, nameFAfile, nameACPCfile, nameVDWinAcpc, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyagerQX.PrintToLog("Created VDW: " + nameVDWinAcpc);
	} else {
		BrainVoyagerQX.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}

function CreateVDWinTalSpace() {

	BrainVoyagerQX.TimeOutMessageBox("This function creates a VDW file in Talairach space...", 5);
	var vmr = BrainVoyagerQX.OpenDocument(nameVMRinTal);
	BrainVoyagerQX.PrintToLog("Start creating VDW in Talairach space...");
//	vmr.ExtendedTALSpaceForVTCCreation = false; // this is true or false
	var success = vmr.CreateVDWInTALSpace(nameDMR, nameIAfile, nameFAfile, nameACPCfile, nameTALfile, nameVDWinTal, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyagerQX.PrintToLog("Created VDW: " + nameVDWinTal);
	} else {
		BrainVoyagerQX.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}
