/* 	ExperimentalDesign.js
	Script for BrainVoyager QX 2.1
*/
/* Declarations */
var ObjectsRawDataPath = "/Users/hester/Data/ObjectsDicomGSG/";
var RFXDataPath = "/Users/hester/Data/Exercise_RFX_ANOVA/";

/* This code is executed when clicking 'Run' */
MakeProtocol(); 
CreateDesignMatrix(); 
CreateMultiStudyDesignMatrix();

/* These functions can be invoked */
function MakeProtocol()
{
	BrainVoyagerQX.PrintToLog("Create stimulation protocol...");
	var doc = BrainVoyagerQX.OpenDocument( ObjectsRawDataPath + "CG2_3DT1FL_SINC4_TAL.vmr" );
	doc.ClearStimulationProtocol();

	doc.StimulationProtocolExperimentName = "Objects Experiment";
	doc.StimulationProtocolResolution = 1;

	doc.AddCondition("Fixation");
	doc.AddCondition("Objects in LVF");
	doc.AddCondition("Objects in RVF");
	doc.AddCondition("Objects in BVF");

	for(interval = 0; interval < 10; interval++)
	{
		intervalstart = interval*27 - 1;
		intervalend   = intervalstart + 8;

		// first interval is shorter:
		if(interval == 0)
		{
			intervalstart = 1;
			intervalend = 7;
		}
		doc.AddInterval("Fixation", intervalstart, intervalend);
	}

	for(interval = 0; interval < 3; interval++)
	{
		intervalstart = 35+interval*81;
		intervalend   = intervalstart + 17;

		doc.AddInterval("Objects in LVF", intervalstart, intervalend);
	}

	for(interval = 0; interval < 3; interval++)
	{
		intervalstart = 8+interval*81;
		intervalend   = intervalstart + 17;

		doc.AddInterval("Objects in RVF", intervalstart, intervalend);
	}

	for(interval = 0; interval < 3; interval++)
	{
		intervalstart = 62+interval*81;
		intervalend   = intervalstart + 17;
   
		doc.AddInterval("Objects in BVF", intervalstart, intervalend);
	}

	doc.SetConditionColor("Fixation", 100, 100, 100);
	doc.SetConditionColor("Objects in LVF", 255, 0, 0);
	doc.SetConditionColor("Objects in RVF", 0, 255, 0);
	doc.SetConditionColor("Objects in BVF", 0, 0, 255);

	doc.StimulationProtocolBackgroundColorR = 0;
	doc.StimulationProtocolBackgroundColorG = 0;
	doc.StimulationProtocolBackgroundColorB = 0;

	doc.StimulationProtocolTimeCourseColorR = 255;
	doc.StimulationProtocolTimeCourseColorG = 255;
	doc.StimulationProtocolTimeCourseColorB = 255;
	doc.StimulationProtocolTimeCourseThickness = 4;

	doc.SaveStimulationProtocol(ObjectsRawDataPath + "CG_OBJECTS_FROMSCRIPT.prt");
	// MessageBox.information(String("NrOfConditions: %1".arg(doc.NrOfStimulationProtocolConditions)));

	doc.Save(); // to save link to protocol permanently
}

function CreateDesignMatrix()
{
	BrainVoyagerQX.PrintToLog("Create single subject design matrix...");
	var doc = BrainVoyagerQX.OpenDocument(ObjectsRawDataPath + "CG2_3DT1FL_SINC4_TAL.vmr" );
	doc.LinkVTC(ObjectsRawDataPath + "CG_OBJECTS_SCRIPT_TAL.vtc");
	doc.LinkStimulationProtocol(ObjectsRawDataPath + "CG_OBJECTS_FROMSCRIPT.prt");
	doc.ClearDesignMatrix();
//	doc.AutoAddConstantPredictor();

	doc.AddPredictor("LVF");
	doc.SetPredictorValuesFromCondition("LVF", "Objects in LVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("LVF");
 
	doc.AddPredictor("RVF");
	doc.SetPredictorValuesFromCondition("RVF", "Objects in RVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("RVF");

	doc.AddPredictor("BVF");
	doc.SetPredictorValuesFromCondition("BVF", "Objects in BVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("BVF");
 
	// You can also set any value at any time point (interval), here we define a linear trend predictor
/*	doc.AddPredictor("Linear Trend");
	for(i = 1; i<= doc.NrOfVolumes; i++)
	{
		value = 0.1*i;
		doc.SetPredictorValues("Linear Trend", i, i, value);
	}
	doc.ScalePredictorValues("Linear Trend", 1.0, false);
*/
//doc.AutoAddConstantPredictor(); 
BrainVoyagerQX.SetCurrentDirectory("/Users/hester/Data/ObjectsDicomGSG/");
//	doc.SaveSingleStudyGLMDesignMatrix("CG_OBJECTS_FROMSCRIPT.rtc");
	doc.SaveSingleStudyGLMDesignMatrix("CG_OBJECTS_FROMSCRIPT.sdm");
}

function CreateMultiStudyDesignMatrix()
{
	var doc = BrainVoyagerQX.OpenDocument(RFXDataPath + "Average_Tal.vmr");
	doc.ClearMultiStudyGLMDefinition();
	var subjName;
	var nrOfSubjects = 17;
	for (i=0; i<nrOfSubjects; i++) {
		subjName = RFXDataPath + "Sub" + (i+1) + "_run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.vtc"; // create subject name
		doc.AddStudyAndDesignMatrix(subjName, RFXDataPath + "run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.sdm"); // now use subject name and always same protocol
	}
	doc.SaveMultiStudyGLMDefinitionFile(RFXDataPath + "MultiStudy_FROMSCRIPT.mdm");

}
